r17795 - in /trunk/libpdf-create-perl: CHANGES META.yml Makefile.PL README debian/changelog image.dat lib/PDF/Create.pm lib/PDF/Image/GIFImage.pm lib/PDF/Image/JPEGImage.pm pdf-logo.gif pdf-logo.jpg sample.gif sample.jpg sample.pl sampleinterlace.gif

dmn at users.alioth.debian.org dmn at users.alioth.debian.org
Tue Mar 18 08:45:40 UTC 2008


Author: dmn
Date: Tue Mar 18 08:45:39 2008
New Revision: 17795

URL: http://svn.debian.org/wsvn/pkg-perl/?sc=1&rev=17795
Log:
* New upstream release

Added:
    trunk/libpdf-create-perl/CHANGES
      - copied unchanged from r17794, branches/upstream/libpdf-create-perl/current/CHANGES
    trunk/libpdf-create-perl/META.yml
      - copied unchanged from r17794, branches/upstream/libpdf-create-perl/current/META.yml
    trunk/libpdf-create-perl/pdf-logo.gif
      - copied unchanged from r17794, branches/upstream/libpdf-create-perl/current/pdf-logo.gif
    trunk/libpdf-create-perl/pdf-logo.jpg
      - copied unchanged from r17794, branches/upstream/libpdf-create-perl/current/pdf-logo.jpg
Removed:
    trunk/libpdf-create-perl/image.dat
    trunk/libpdf-create-perl/sample.gif
    trunk/libpdf-create-perl/sample.jpg
    trunk/libpdf-create-perl/sampleinterlace.gif
Modified:
    trunk/libpdf-create-perl/Makefile.PL
    trunk/libpdf-create-perl/README
    trunk/libpdf-create-perl/debian/changelog
    trunk/libpdf-create-perl/lib/PDF/Create.pm
    trunk/libpdf-create-perl/lib/PDF/Image/GIFImage.pm
    trunk/libpdf-create-perl/lib/PDF/Image/JPEGImage.pm
    trunk/libpdf-create-perl/sample.pl

Modified: trunk/libpdf-create-perl/Makefile.PL
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/Makefile.PL?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/Makefile.PL (original)
+++ trunk/libpdf-create-perl/Makefile.PL Tue Mar 18 08:45:39 2008
@@ -5,7 +5,7 @@
 WriteMakefile(NAME         => "PDF::Create",
               VERSION_FROM => "lib/PDF/Create.pm",
               dist         => { COMPRESS => "gzip", SUFFIX => "gz" },
-              clean        => { FILES => '*.bak *.old mibs/*.dump ' .
+              clean        => { FILES => '*.bak *.old mibs/*.dump *.pdf' .
                                          'lib/*/*~ lib/*/*/*~' },
               # EXE_FILES  => [ qw() ],
 );

Modified: trunk/libpdf-create-perl/README
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/README?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/README (original)
+++ trunk/libpdf-create-perl/README Tue Mar 18 08:45:39 2008
@@ -15,6 +15,12 @@
     Documents are constructed on the fly so the memory footprint is
     not tied to the size of the pages but only to their number.
 
+    It's main advantage over the other PDF modules is that it does
+    not depend on other modules and is perl only (no compiler needed).
+    If you want a quick and dirty way of creating pdf's, PDF::Create
+    is for you. If you need a complete Framework to create complex
+    PDF stuff, you better dive into the PDF::API2 based modules.
+    
     More information about this module is included in this package.
 
   SYNOPSIS
@@ -44,8 +50,7 @@
         my $toc = $pdf->new_outline('Title' => 'Document',
                                     'Destination' => $page);
         $toc->new_outline('Title' => 'Section 1');
-        my $s2 = $toc->new_outline('Title' => 'Section 2',
-                                   'Status' => 'closed');
+        my $s2 = $toc->new_outline('Title' => 'Section 2');
         $s2->new_outline('Title' => 'Subsection 1');
 
         $page->stringc($f2, 40, 306, 426, "PDF::Create");
@@ -61,9 +66,9 @@
 
         # Add something to the first page
         $page->stringc($f1, 20, 306, 300,
-                       'by Fabien Tassin <fta at sofaraway.org>');
+                       'by Fabien Tassin <fta at oleane.net>');
 
-        # Add the missing PDF objects and the footer then close the file
+        # Add the missing PDF objects and a the footer then close the file
         $pdf->close;
 
 
@@ -94,3 +99,18 @@
             make
             make test
             make pure_install
+
+  AUTHORS
+
+    - Fabien Tassin
+
+    Original Author of PDF::Create
+
+    - Markus Baertschi, markus at markus.org
+
+    I have taken over maintenence of PDF::Create as Fabien has disappeared
+    and did no longer maintain it in the last years.
+    The last version of PDF::Create from Fabien is 0.06. All never versions
+    have been modified by me.
+
+

Modified: trunk/libpdf-create-perl/debian/changelog
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/debian/changelog?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/debian/changelog (original)
+++ trunk/libpdf-create-perl/debian/changelog Tue Mar 18 08:45:39 2008
@@ -1,5 +1,6 @@
-libpdf-create-perl (0.06.1b-6) UNRELEASED; urgency=low
+libpdf-create-perl (0.08-1) UNRELEASED; urgency=low
 
+  [ gregor herrmann ]
   * debian/control: Added: Vcs-Svn field (source stanza); Vcs-Browser
     field (source stanza); Homepage field (source stanza). Removed:
     Homepage pseudo-field (Description); XS-Vcs-Svn fields.
@@ -10,7 +11,10 @@
     locations.
   * debian/rules: delete /usr/lib/perl5 only if it exists.
 
- -- gregor herrmann <gregor+debian at comodo.priv.at>  Mon, 03 Mar 2008 21:21:26 +0100
+  [ Damyan Ivanov ]
+  * New upstream release
+
+ -- Damyan Ivanov <dmn at debian.org>  Tue, 18 Mar 2008 10:42:41 +0200
 
 libpdf-create-perl (0.06.1b-5) unstable; urgency=low
 

Modified: trunk/libpdf-create-perl/lib/PDF/Create.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/lib/PDF/Create.pm?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/lib/PDF/Create.pm (original)
+++ trunk/libpdf-create-perl/lib/PDF/Create.pm Tue Mar 18 08:45:39 2008
@@ -1,12 +1,16 @@
 # -*- mode: Perl -*-
-
+#
 # PDF::Create - create PDF files
+#
 # Author: Fabien Tassin <fta at sofaraway.org>
-# Version: 0.06
+#
+# Version: 0.08
+#
 # Copyright 1999-2001 Fabien Tassin <fta at sofaraway.org>
-
-# bugs:
-# - ...
+# Copyright 2007  Markus Baertschi
+#
+# 03.09.2007  0.08  Markus Baertschi
+#                   - Fixed error cheking on file open
 
 package PDF::Create;
 
@@ -22,7 +26,7 @@
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw();
-$VERSION = 0.06;
+$VERSION = 0.08;
 $DEBUG   = 0;
 
 sub new {
@@ -53,8 +57,8 @@
   elsif (defined $params{'filename'}) {
     $self->{'filename'} = $params{'filename'};
     my $fh = new FileHandle "> $self->{'filename'}";
+    carp "PDF::Create.pm: $self->{'filename'}: $!\n" unless defined $fh;
     binmode $fh;
-    carp "Error: can't open $self->{'filename'}: $!\n" unless defined $fh;
     $self->{'fh'} = $fh;
   }
   $self->{'catalog'} = {};
@@ -446,6 +450,7 @@
      'a2'         => [ 0, 0, 1190, 1684 ],
      'a3'         => [ 0, 0, 842,  1190 ],
      'a4'         => [ 0, 0, 595,  842  ],
+     'a4L'        => [ 0, 0, 842,  595  ],
      'a5'         => [ 0, 0, 421,  595  ],
      'a6'         => [ 0, 0, 297,  421  ],
      'letter'     => [ 0, 0, 612,  792  ],
@@ -900,6 +905,9 @@
 			      'CreationDate' => [ localtime ],
 			 );
     my $root = $pdf->new_page('MediaBox' => [ 0, 0, 612, 792 ]);
+	
+	# add a A4 sized page
+    my $root = $pdf->new_page('MediaBox' => $pdf->get_page_size('A4'));
 
     # Add a page which inherits its attributes from $root
     my $page = $root->new_page;
@@ -1278,6 +1286,8 @@
 
 GIF and JPEG-support: Michael Gross (mdgrosse at sbox.tugraz.at)
 
+Maintenence since 2007: Markus Baertschi (markus at markus.org)
+
 =head1 COPYRIGHT
 
 Copyright 1999-2001, Fabien Tassin. All rights reserved.

Modified: trunk/libpdf-create-perl/lib/PDF/Image/GIFImage.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/lib/PDF/Image/GIFImage.pm?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/lib/PDF/Image/JPEGImage.pm (original)
+++ trunk/libpdf-create-perl/lib/PDF/Image/JPEGImage.pm Tue Mar 18 08:45:39 2008
@@ -2,10 +2,13 @@
 
 # PDF::Image::JPEGImage - JPEG image support
 # Author: Michael Gross <mdgrosse at sbox.tugraz.at>
-# Version: 0.06
+# Version: 0.07
 # Copyright 2001 Michael Gross <mdgrosse at sbox.tugraz.at>
+# Copyright 2007 Markus Baertschi <markus at markus.org>
 #
 # 27.11.2001 - Bugfix, now also works on Windows (binmode) 
+# 03.09.2007  0.07  Markus Baertschi
+#                   - Added error checking on file open
 
 package JPEGImage;
 use strict;
@@ -15,7 +18,7 @@
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw();
-$VERSION = 0.06;
+$VERSION = 0.07;
 $DEBUG   = 0;
 
 sub new {
@@ -156,6 +159,7 @@
     my $components = 0;
 
     my $fh = new FileHandle $filename;
+    if (!defined $fh) { $self->{error} = "JPEGImage.pm: $filename: $!"; return 0 }
     binmode $fh;
     
     #Tommy's special trick for Macintosh JPEGs: simply skip some
@@ -169,7 +173,7 @@
 
         if (eof($fh)) {
             close($fh);
-            $self->{error} = "Not a JPEG file.";
+            $self->{error} = "JPEGImage.pm: Not a JPEG file.";
             return 0;
         }
 
@@ -192,7 +196,7 @@
     # handle - regard as hopeless...
     if (eof($fh) || $self->{private}->{datapos} > $BOGUS_LENGTH) {
         close($fh);
-        $self->{error} = "Not a JPEG file.";
+        $self->{error} = "JPEGImage.pm: Not a JPEG file.";
         return 0;
     }
 
@@ -201,13 +205,13 @@
         #print "Marker: " . sprintf("%x", $c) . "\n";
         if ($c==$M_ERROR || $c==$M_SOF3 || $c==$M_SOF5 || $c==$M_SOF6 || $c==$M_SOF7 || $c==$M_SOF9 || $c==$M_SOF11 || $c==$M_SOF13 || $c==$M_SOF14 || $c==$M_SOF15) {
             close($fh);
-            $self->{error} = "JPEG compression " . ord($c) . " not supported in PDF 1.3.",
+            $self->{error} = "JPEGImage.pm: JPEG compression " . ord($c) . " not supported in PDF 1.3.",
             return 0;
         }    
 
         if ($c==$M_SOF2 || $c==$M_SOF10) {
             close($fh);
-            $self->{error} = "JPEG compression " . ord($c) . " not supported in PDF 1.2.",
+            $self->{error} = "JPEGImage.pm: JPEG compression " . ord($c) . " not supported in PDF 1.2.",
             return 0;
         }    
 
@@ -267,13 +271,13 @@
 
     if ($self->{height} <= 0 || $self->{width} <= 0 || $components <= 0) {
         close($fh);
-        $self->{error} = "Bad image parameters in JPEG file.";
+        $self->{error} = "JPEGImage.pm: Bad image parameters in JPEG file.";
         return 0;
     }
 
     if ($self->{bpc} != 8) {
         close($fh);
-        $self->{error} = "Bad bpc in JPEG file.";
+        $self->{error} = "JPEGImage.pm: Bad bpc in JPEG file.";
         return 0;
     }
 
@@ -289,7 +293,7 @@
         }
     } else {       
         close($fh);
-        $self->{error} = "Unknown number of color components in JPEG file.",
+        $self->{error} = "JPEGImage.pm: Unknown number of color components in JPEG file.",
         return 0;
     }
 
@@ -304,6 +308,7 @@
     my $result;
     my $JPEG_BUFSIZE = 1024;
     my $fh = new FileHandle $self->{filename};
+    if (!defined $fh) { $self->{error} = "JPEGImage.pm: $self->{filename}: $!"; return 0 }
     binmode $fh;
     seek($fh, $self->{private}->{datapos}, 0);
     

Modified: trunk/libpdf-create-perl/sample.pl
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/sample.pl?rev=17795&op=diff
==============================================================================
--- trunk/libpdf-create-perl/sample.pl (original)
+++ trunk/libpdf-create-perl/sample.pl Tue Mar 18 08:45:39 2008
@@ -1,167 +1,65 @@
 #!/usr/bin/perl -w
+#
+# sample PDF::Create usage
+#
 
 BEGIN { unshift @INC, "lib", "../lib" }
 use strict;
-
 use PDF::Create;
 
-my $f1;
-my $f2;
-my $f3;
+my $pdf = new PDF::Create('filename' => 'sample.pdf',
+		   			      'Version'  => 1.2,
+					      'PageMode' => 'UseOutlines',
+					      'Author'   => 'Fabien Tassin',
+						  'Title'    => 'Sample Document',
+						);
 
-sub Coord {
-  my $page = shift;
-  my $x = shift;
-  my $y = shift;
-  my $s = shift;
-  
-  $page->line($x-60, $y, $x+60, $y);
-  $page->line($x, $y-45, $x, $y+65);
-  $page->line($x, $y+65, $x+2.5, $y+60);
-  $page->line($x, $y+65, $x-2.5, $y+60);
-  $page->line($x+60, $y, $x+55, $y+2.5);
-  $page->line($x+60, $y, $x+55, $y-2.5);
-  
-  $page->line($x-82.5, $y-80, $x+82.5, $y-80);
-  $page->line($x-82.5, $y-80, $x-82.5, $y+80);
-  $page->line($x+82.5, $y-80, $x+82.5, $y+80);
-  $page->line($x-82.5, $y+80, $x+82.5, $y+80);
-  
-  my @s = split("\n", $s);
-  foreach $s (@s) {
-      $page->stringc($f1, 8, $x, $y-60, $s);
-      $y-=10;
-  }    
-}
+my $root = $pdf->new_page('MediaBox' => $pdf->get_page_size('A4'));
 
+# Prepare 2 fonts
+my $f1 = $pdf->font('Subtype'  => 'Type1',
+	 	   	        'Encoding' => 'WinAnsiEncoding',
+			        'BaseFont' => 'Helvetica');
+my $f2 = $pdf->font('Subtype'  => 'Type1',
+			        'Encoding' => 'WinAnsiEncoding',
+			        'BaseFont' => 'Helvetica-Bold');
 
-my $pdf = new PDF::Create('filename' => 'mypdf.pdf',
-			  'Version'  => 1.2,
-			  'PageMode' => 'UseOutlines',
-			  'Author'   => 'Fabien Tassin',
-			  'Title'    => 'My title',
-			 );
-my $root = $pdf->new_page('MediaBox'  => $pdf->get_page_size("letter"));
+# Prepare a Table of Content
+my $toc = $pdf->new_outline('Title' => 'Sample Document');
 
 # Add a page which inherits its attributes from $root
 my $page = $root->new_page;
+# Add a entry to the outline
+$toc->new_outline('Title' => 'Page 1', 'Destination' => $page);
 
-    # Prepare 2 fonts
-    $f1 = $pdf->font('Subtype'  => 'Type1',
- 	   	        'Encoding' => 'WinAnsiEncoding',
- 		        'BaseFont' => 'Helvetica');
-    $f2 = $pdf->font('Subtype'  => 'Type1',
- 		        'Encoding' => 'WinAnsiEncoding',
- 		        'BaseFont' => 'Helvetica-Bold');
+# Write some text to the page
+$page->stringc($f2, 40, 306, 426, "PDF::Create");
+$page->stringc($f1, 20, 306, 396, "version $PDF::Create::VERSION");
+$page->stringc($f1, 20, 300, 300, 'Fabien Tassin');
+$page->stringc($f1, 20, 300, 250, 'Markus Baertschi (markus at markus.org)');
 
-    $f3 = $pdf->font('Subtype'  => 'Type1',
- 		        'Encoding' => 'WinAnsiEncoding',
- 		        'BaseFont' => 'Courier');
+# add another page
+my $page2 = $root->new_page;
+my $s2 = $toc->new_outline('Title' => 'Page 2', 'Destination' => $page2);
+$s2->new_outline('Title' => 'GIF');
+$s2->new_outline('Title' => 'JPEG');
 
+# Draw a border around the page (A4 max is 595/842)
+$page2->line(10, 10, 10, 832);
+$page2->line(10, 10, 585, 10);
+$page2->line(10, 832, 585, 832);
+$page2->line(585, 10, 585, 832);
 
-    # Prepare a Table of Content
-    my $toc = $pdf->new_outline('Title' => 'Document',
-                                'Destination' => $page);
-    $toc->new_outline('Title' => 'Section 1');
-    my $s2 = $toc->new_outline('Title' => 'Section 2', 'Status' => 'closed');
-    $s2->new_outline('Title' => 'Subsection 1');
+# Add a gif image
+$page2->string($f1, 20, 50, 600, 'GIF Image:');
+my $img1 = $pdf->image('pdf-logo.gif');
+$page2->image('image'=>$img1, 'xscale'=>0.2,'yscale'=>0.2,'xpos'=>200,'ypos'=>600);
 
-    $page->stringc($f2, 40, 306, 426, "PDF::Create");
-    $page->stringc($f1, 20, 306, 396, "version $PDF::Create::VERSION");
+# Add a jpeg image
+$page2->string($f1, 20, 50, 500, 'JPEG Image:');
+my $img2 = $pdf->image('pdf-logo.jpg');
+$page2->image('image'=>$img2, 'xscale'=>0.2,'yscale'=>0.2,'xpos'=>200,'ypos'=>500);
 
-    # Add another page
-    my $page2 = $root->new_page;
-    $page2->line(0, 0, 612, 792);
-    $page2->line(0, 792, 612, 0);
+# Wrap up the PDF and close the file
+$pdf->close;
 
-$toc->new_outline('Title' => 'Section 3');
-$pdf->new_outline('Title' => 'Summary');
-
-# Add something to the first page
-$page->stringc($f1, 20, 306, 300, 'by Fabien Tassin <fta at sofaraway.org>');
-
-
-    # Add images presentation
-    my $gif = $pdf->image("sample.gif");
-    my $gifinterlace = $pdf->image("sampleinterlace.gif");
-    my $jpg = $pdf->image("sample.jpg");
-
-    $page2 = $root->new_page;
-    $toc->new_outline('Title' => 'Images', 'Destination' => $page2);
-
-
-    my $y;
-    my $x; 
-    $y = 725;
-    $page2->stringc($f2, 20, 300, $y, 'Image Support');
-    $y-=25;
-    $page2->stringl($f1, 13, 50, $y, 'Support for GIF and JPEG-Images by Michael Gross mdgrosse at sbox.tugraz.at.');
-    $y-=20;
-    $page2->stringl($f1, 10, 50, $y, 'Usage:');
-    $y-=15;
-    $page2->stringl($f3, 10, 60, $y, '$image = $pdf->image(filename)');
-    $y-=15;
-    $page2->stringl($f1, 10, 70, $y, 'Creates xobject for image <filename>.');
-    $y-=20;
-    $page2->stringl($f3, 10, 60, $y, '$page->image(image, x, y, alignx, aligny, ');
-    $y-=15;
-    $page2->stringl($f3, 10, 60, $y, '  scalex, scaley, rotation, scewx, scewy)');
-    $y-=15;
-    $page2->stringl($f1, 10, 70, $y, 'Inserts <image> into <$page> at position <x>, <y>.');
-    $y-=15;
-    $page2->stringl($f3, 10, 70, $y, 'alignx, aligny');
-    $page2->stringl($f1, 10, 200, $y, 'Alignment of image. 0 is left/bottom, 1 centered, 2 right/top.');
-    $y-=15;
-    $page2->stringl($f3, 10, 70, $y, 'scalex, scaley');
-    $page2->stringl($f1, 10, 200, $y, 'Scaling of image. 1 for original size.');
-    $y-=15;
-    $page2->stringl($f3, 10, 70, $y, 'rotation');
-    $page2->stringl($f1, 10, 200, $y, 'Image rotation, 0 for no rotation, 2*pi for 360°.');
-    $y-=15;
-    $page2->stringl($f3, 10, 70, $y, 'scewx, scewy');
-    $page2->stringl($f1, 10, 200, $y, 'Image scew.');
-
-    $y = 450;
-    $x = 125;    
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos'=>\$y)");
-    
-    $x+=165;
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'xalign' => 1, 'yalign' => 1);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos' => \$y, 'xalign' => 1, 'yalign' => 1)");
-    
-    $x+=165;
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'xalign' => 2, 'yalign' => 2);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos' => \$y, 'xalign' => 2, 'yalign' => 2)");
-
-
-    $y-=160;
-    $x = 125;    
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'xscale' => 2, yscale => '0.5');
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos' => \$y, 'xscale' => 2, yscale => '0.5')");
-    
-    $x+=165;
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'rotate' => 0.7);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => '$x, \n'ypos' => \$y, 'rotate' => 0.7)");
-    
-    $x+=165;
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'xskew' => 0.7);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos' => \$y, 'xskew' => 0.7)");
-
-
-    $y-=160;
-    $x = 125;    
-    $page2->image('image' => $gif, 'xpos' => $x, 'ypos'=>$y, 'yskew' => 0.7);
-    Coord($page2, $x, $y, "image('image' => \$gif, 'xpos' => \$x, \n'ypos' => \$y, 'yskew' => 0.7)");
-    
-    $x+=165;
-    $page2->image('image' => $gifinterlace, 'xpos' => $x, 'ypos'=>$y);
-    Coord($page2, $x, $y, 'interlaced GIF');
-    
-    $x+=165;
-    $page2->image('image' => $jpg, 'xpos' => $x, 'ypos'=>$y);
-    Coord($page2, $x, $y, 'JPEG image');
-
-
-# Add the missing PDF objects and a the footer then close the file
-$pdf->close;




More information about the Pkg-perl-cvs-commits mailing list
--- trunk/libpdf-create-perl/lib/PDF/Image/GIFImage.pm (original)
+++ trunk/libpdf-create-perl/lib/PDF/Image/GIFImage.pm Tue Mar 18 08:45:39 2008
@@ -2,11 +2,14 @@
 
 # PDF::Image::GIFImage - GIF image support
 # Author: Michael Gross <mdgrosse at sbox.tugraz.at>
-# Version: 0.06
+# Version: 0.07
 # Copyright 2001 Michael Gross <mdgrosse at sbox.tugraz.at>
+# Copyright 2007 Markus Baertschi <markus at markus.org>
 #
 # 10.9.2001 - Bugfix for Perl 5.6
 # 27.11.2001 - Bugfix, now also works on Windows (binmode) 
 
 package GIFImage;
 use strict;
@@ -16,7 +19,7 @@
 
 @ISA     = qw(Exporter);
 @EXPORT  = qw();
-$VERSION = 0.06;
+$VERSION = 0.07;
 $DEBUG   = 0;
 
 sub new {
@@ -361,18 +364,19 @@
     
     $self->{filename} = $filename;
     my $fh = new FileHandle "$filename";
+    if (!defined $fh) { $self->{error} = "GIFImage.pm: $filename: $!"; return 0 }
     binmode $fh;
     read $fh, $s, 3;
     if ($s ne $PDF_STRING_GIF) {
         close $fh;
-        $self->{error} = "Not a gif file.";
+        $self->{error} = "GIFImage.pm: Not a gif file.";
         return 0;
     }
     
     read $fh, $s, 3;
     if ($s ne $PDF_STRING_87a && $s ne $PDF_STRING_89a) {
         close $fh;
-        $self->{error} = "GIF version $s not supported.";
+        $self->{error} = "GIFImage.pm: GIF version $s not supported.";
         return 0;
     }
         
@@ -384,7 +388,7 @@
     if ($flags & $LOCALCOLORMAP) {
         if (!$self->ReadColorMap($fh)) {
             close $fh;
-            $self->{error} = "Cant read color map.";
+            $self->{error} = "GIFImage.pm: Cant read color map.";
             return 0;
         }
     }
@@ -401,7 +405,7 @@
         read $fh, $c, 1;
         if ($c eq ";") {  #GIF file terminator
             close $fh;
-            $self->{error} = "Cant find image in gif file.";
+            $self->{error} = "GIFImage.pm: Cant find image in gif file.";
             return 0;
         }   
         
@@ -428,7 +432,7 @@
         if ($flags & $LOCALCOLORMAP) {            
             if (!$self->ReadColorMap($fh)) {
                 close $fh;
-                $self->{error} = "Cant read color map.";
+                $self->{error} = "GIFImage.pm: Cant read color map.";
                 return 0;
             }
         }
@@ -437,7 +441,7 @@
         $self->{bpc} = unpack("C", $s);
         if ($self->{bpc} != 8) {
             close $fh;
-            $self->{error} = "LZW minimum code size other than 8 not supported.";
+            $self->{error} = "GIFImage.pm: LZW minimum code size other than 8 not supported.";
             return 0;
         }
             
@@ -477,6 +481,7 @@
     my $result = "";
         
     my $fh = new FileHandle $self->{filename};
+    if (!defined $fh) { $self->{error} = "GIFImage.pm: $self->{filename}: $!"; return 0 }
     binmode $fh;
     seek($fh, $self->{private}->{datapos}, 0);
     my $pos = 0;
@@ -518,7 +523,7 @@
             $i_buff >>= $c_size;
 
             if ($flag13 && $code!=256 && $code!=257) {
-                $self->{error} = "LZW code size overflow.";
+                $self->{error} = "GIFImage.pm: LZW code size overflow.";
                 return 0;
             }
 
@@ -2,11 +2,14 @@
 #
-# 10.9.2001 - Bugfix for Perl 5.6
-# 27.11.2001 - Bugfix, now also works on Windows (binmode) 
+# 10.9.2001   -     Bugfix for Perl 5.6
+# 27.11.2001  -     Bugfix, now also works on Windows (binmode) 
+# 03.09.2007  0.07  Markus
+#                   - Added error checking after file open
 
 package GIFImage;

Modified: trunk/libpdf-create-perl/lib/PDF/Image/JPEGImage.pm
URL: http://svn.debian.org/wsvn/pkg-perl/trunk/libpdf-create-perl/lib/PDF/Image/JPEGImage.pm?rev=17795&op=diff
==============================================================================